**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             modelEco_var1
Sequence         1 - Introduction to mathematical programming using GAMS
Type             LP
GAMS language    Infeasible problem
Description
Adding gross margin calculation
" A given farm can produce two crops: wheat and maize.
We are looking to determine the area dedicated to each crop, knowing that:
The farmer's objective is to maximize his income
The yield of wheat is 5 tonnes per hectare and that of maize 10 tonnes.
Their production costs are 300/ha and 500/ha, respectively.
Both cereals are sold at 150/tonne.
Wheat requires 25 hours of labour per hectare and per year and maize 50 hours of labour .
The area of the farm is 50 ha and the farmer can work 2000 hours in a year.
Imagine that to ensure the food supply of cities,
the government requires each farmer to grow at least 80 ha of cereals. "
$Offtext
*-----------------------------------------------------------------------------*

*----------                         DECLARATIONS                       ----------*
sets
C crops  /wheat,maize/
;

*----------                          DATA                        ----------*
scalar
LAND_A      land availability in hectares                 /50/
LABOUR_A    labour availability in hours                /2000/
CERE        minimum area dedicated to cereals             /80/
;

parameter
LN(C) labour needs per hectare and per crop (hours)
/wheat   25
 maize   50/


YLD (C) yield per crop in tonnes per hectare
/ wheat 5
 maize 10/

PC (C) selling price per crop in euros
/ wheat 150
 maize  150/

COST (C) cost per crop in euros per ha
/ wheat 300
 maize  500/
;

parameter
GM(C) gross margin per crop in euros    ;
GM(C) = YLD(C)*PC(C)-COST(C);

*----------                         MODEL                          ----------*
variables
Z   total farm income  (euros)
;

positive variables
X area per crop (hectares)
;

equations
OBJECTIVE       objective function
LAND            land equation
LABOUR          labour equation
CEREALS
;

OBJECTIVE..   sum(c, GM(c)*X(c)) =E= Z ;

LAND..        sum(c, X(c)) =l= LAND_A ;

LABOUR..      sum(c, LN(c)*X(c)) =L= LABOUR_A  ;

CEREALS ..    sum (c, X(c))=g= CERE ;

model example first example /all/;

*----------                        SOLUTION                         ----------*
solve example using LP maximizing Z;

